@@ -2,7 +2,7 @@ fluidPage(
   useShinyjs(),
   tags$link(rel = "stylesheet", href = "app.css"),
   tags$link(rel = "stylesheet", href = "table1-style.css"),
-  titlePanel("Hello ggquickeda!"),
+  titlePanel("Welcome to ggquickeda!"),
   sidebarLayout(
     sidebarPanel(
       tabsetPanel(
@@ -25,6 +25,14 @@ fluidPage(
               shinyjs::hidden(
                 sliderInput('ncuts',label = 'N of Cut Breaks:', min=2, max=10, value=c(2),step=1)
               ),
+              uiOutput("catvarquant"),
+              shinyjs::hidden(
+                sliderInput('ncutsquant',label = 'N of Quantiles:', min=2, max=10, value=c(2),step=1),
+                checkboxInput('zeroplacebo', 'Zero as Placebo ?', value = FALSE),
+                checkboxInput('missingcategory', 'Missing as a Category ?', value = FALSE)
+                
+              ),
+              
               uiOutput("catvar2"),
               uiOutput("catvar3"),
               uiOutput("ncuts2"),
@@ -32,6 +40,15 @@ fluidPage(
               textOutput("bintext")
 
             ),
+            tabPanel(
+              "Merge factor levels",
+              shinyjs::hidden(div(
+                id = "factor_merge_section",
+                div(id = "factor_merge_placeholder"),
+                actionButton("factor_merge_add", "Merge another group", icon("plus")),
+                actionButton("factor_merge_remove", "Remove last merge", icon("trash"))
+              ))
+            ),
             tabPanel(
               "Recode/Reorder Categories",
               shinyjs::hidden(div(
@@ -40,7 +57,7 @@ fluidPage(
                 actionButton("factor_lvl_change_add", "Add another variable", icon("plus")),
                 actionButton("factor_lvl_change_remove", "Remove last", icon("trash"))
               ))
-              ),
+            ),
             tabPanel("Combine Two Variables",
                      h6("Combined variables can be used for colour, fill, group, size and facets. They cannot be used as X or Y variables."),
                      
@@ -64,7 +81,8 @@ fluidPage(
             ),
             tabPanel(
               "One Row by ID(s)",
-                uiOutput("onerowidgroup")
+                uiOutput("onerowidgroup"),
+                uiOutput("onerowidlastgroup")
  
             ),
             
@@ -82,7 +100,7 @@ fluidPage(
                 condition = "input.reordervarin!='' " ,
                 selectizeInput(
                   "functionordervariable", 'By the:',
-                  choices =c("Median","Mean","Minimum","Maximum") ,multiple=FALSE)
+                  choices =c("Median","Mean","Minimum","Maximum","N") ,multiple=FALSE)
               ),
               uiOutput("variabletoorderby"),
               conditionalPanel(
@@ -199,7 +217,7 @@ fluidPage(
                 conditionalPanel(condition = "input.xaxiszoom=='userxzoom' ",uiOutput("upperx")) )
               ),# fluidrow
   
-              h6("Y Axis Zoom only works if you have exactly one y variable and facet y scales are not set to be free. The automatic setting generate a slider has limits between your y variable min/max otherwise select User Defined to input your own."),
+              h6("Y Axis Zoom is available if you have exactly one y variable and facet y scales are not set to be free. The automatic setting generates a slider has limits between your y variable min/max otherwise select User Defined to input your own."),
               fluidRow(
                 column(12,
                        radioButtons("yaxiszoom", "Y Axis Zoom:",
@@ -261,12 +279,9 @@ fluidPage(
             ),
             tabPanel(
               "Facets Options",
-              
               uiOutput("facetscales"),
               selectInput('facetspace' ,'Facet Spaces:',c("fixed","free_x","free_y","free")),
-              
-              
-              selectInput('facetordering' ,'Facet Ordering:',c(
+               selectInput('facetordering' ,'Facet Ordering:',c(
                 "Top to Bottom, Left to Right Ordering like a Table" ="table",
                 "Bottom to Top, Left to Right Ordering like a Plot" ="plot"),
                 selected="table"),
@@ -274,10 +289,8 @@ fluidPage(
               conditionalPanel(
                 condition = "!input.facetwrap" ,
                 selectizeInput(  "facetswitch", "Facet Switch to Near Axis:",
-                                 choices = c("x","y","both"),
-                                 options = list(  maxItems = 1 ,
-                                                  placeholder = 'Please select an option',
-                                                  onInitialize = I('function() { this.setValue(""); }')  )  ),
+                                 choices = c("none","x","y","both"),
+                                 options = list(  maxItems = 1 )  ),
                 checkboxInput('facetmargin', 'Show a facet with all data (margins)?'),
                 selectInput('facetlabeller' ,'Facet Label:',c(
                   "Variable(s) Name(s) and Value(s)" ="label_both",
@@ -300,7 +313,29 @@ fluidPage(
                    The default empty values will use ggplot automatic algorithm."),        
                 numericInput("wrapncol",label = "N columns",value =NA,min=1,max =10) ,
                 numericInput("wrapnrow",label = "N rows",value = NA,min=1,max=10) 
-                )
+                ),
+              colourpicker::colourInput("stripbackgroundfillx",
+                                        "X Strip Background Fill:",
+                                        value="#E5E5E5",
+                                        showColour = "both",allowTransparent=TRUE),
+              div( actionButton("stripbackfillresetx", "Reset X Strip Background Fill"),
+                   style="text-align: right"),
+              colourpicker::colourInput("stripbackgroundfilly",
+                                        "Y Strip Background Fill:",
+                                        value="#E5E5E5",
+                                        showColour = "both",allowTransparent=TRUE),
+              div( actionButton("stripbackfillresety", "Reset Y Strip Background Fill"),
+                   style="text-align: right"),
+              
+              selectizeInput(  "stripplacement", "Strip Placement:",
+                               choices = c("inside","outside"),
+                               options = list(  maxItems = 1 )  ),
+              
+              sliderInput("panelspacingx", label = "Facets X Spacing:",
+                          min = 0, max = 2, value = 0.25, step = 0.05),
+              sliderInput("panelspacingy", label = "Facets Y Spacing:",
+                          min = 0, max = 2, value = 0.25, step = 0.05)
+              
               ) ,
             
             tabPanel(
@@ -309,16 +344,36 @@ fluidPage(
               checkboxInput('horizontalzero', 'Horizontal Zero Line'),
               checkboxInput('customvline1', 'Vertical Line 1'),
               conditionalPanel(condition = "input.customvline1" , 
-                               numericInput("vline1",label = "",value = 1) ),
+                               numericInput("vline1",label = "",value = 1),
+                               colourpicker::colourInput("vlinecol1", "Line Color:", "gray",showColour = "both",allowTransparent=TRUE),
+                               div( actionButton("vlinecol1reset", "Reset Line Color"), style="text-align: right"),
+                               selectInput('vlinetype1','Line Type:',c("solid","dotted","dashed")),
+                               sliderInput("vlinesize1", "Line Size:", min=0, max=4, value=c(1),step=0.1)
+                               ),
               checkboxInput('customvline2', 'Vertical Line 2'),
               conditionalPanel(condition = "input.customvline2" , 
-                               numericInput("vline2",label = "",value = 1) ),
+                               numericInput("vline2",label = "",value = 1) ,
+                               colourpicker::colourInput("vlinecol2", "Line Color:", "gray",showColour = "both",allowTransparent=TRUE),
+                               div( actionButton("vlinecol2reset", "Reset Line Color"), style="text-align: right"),
+                               selectInput('vlinetype2','Line Type:',c("solid","dotted","dashed")),
+                               sliderInput("vlinesize2", "Line Size:", min=0, max=4, value=c(1),step=0.1) 
+                               ),
               checkboxInput('customhline1', 'Horizontal Line 1'),
               conditionalPanel(condition = "input.customhline1" , 
-                               numericInput("hline1",label = "",value = 1) ),
+                               numericInput("hline1",label = "",value = 1),
+                               colourpicker::colourInput("hlinecol1", "Line Color:", "gray",showColour = "both",allowTransparent=TRUE),
+                               div( actionButton("hlinecol1reset", "Reset Line Color"), style="text-align: right"),
+                               selectInput('hlinetype1','Line Type:',c("solid","dotted","dashed")),
+                               sliderInput("hlinesize1", "Line Size:", min=0, max=4, value=c(1),step=0.1)
+                               
+                               ),
               checkboxInput('customhline2', 'Horizontal Line 2'),
               conditionalPanel(condition = "input.customhline2" , 
-                               numericInput("hline2",label = "",value = 1) ),
+                               numericInput("hline2",label = "",value = 1),
+                               colourpicker::colourInput("hlinecol2", "Line Color:", "gray",showColour = "both",allowTransparent=TRUE),
+                               div( actionButton("hlinecol2reset", "Reset Line Color"), style="text-align: right"),
+                               selectInput('hlinetype2','Line Type:',c("solid","dotted","dashed")),
+                               sliderInput("hlinesize2", "Line Size:", min=0, max=4, value=c(1),step=0.1) ),
               checkboxInput('showtarget', 'Add Target Window', value = FALSE) ,
               conditionalPanel(condition = "input.showtarget" , 
                                numericInput("uppertarget",label = "Upper Target Value",
@@ -333,13 +388,23 @@ fluidPage(
               conditionalPanel(condition = "input.showtargettext" ,
                                textInput('targettext', 'Target Text', value = "Target: XX-XXX µg/mL"),
                                sliderInput("targettextsize", "Target Text Size:", min=1, max=10, value=c(5),step=0.5),
-                               colourInput("targettextcol", "Target Text Color:", "blue",showColour = "both")
+                               colourInput("targettextcol", "Target Text Color:", "blue",showColour = "both"),
+                               sliderInput("targettextvjust", "Target Text Vertical Justification:", min=0, max=1, value=c(1),step=0.1),
+                               sliderInput("targettexthjust", "Target Text Horizontal Justification:", min=0, max=1, value=c(0),step=0.1),
+                               numericInput("targettextxpos",label = "Target Text X Position",
+                                            value = 1,min=NA,max=NA,width='50%'),
+                               numericInput("targettextypos",label = "Target Text Y Position",
+                                            value = 1,min=NA,max=NA,width='50%')
                                )
               
             ),
             tabPanel(
               "Additional Themes Options",
-              sliderInput("themebasesize", "Theme Size (affects all text elements in the plot):", min=1, max=100, value=c(16),step=1),
+              sliderInput("themebasesize", "Theme Size (affects all text except facet strip):", min=1, max=100, value=c(16),step=1),
+              sliderInput("striptextsizex", "X Strip Text Size:",
+                          min=1, max=100, value=c(16),step=0.5),
+              sliderInput("striptextsizey", "Y Strip Text Size:",
+                          min=1, max=100, value=c(16),step=0.5),
               radioButtons("themecolorswitcher", "Discrete Color and Fill Themes:",
                            c("Tableau 10"  = "themetableau10",
                              "Tableau 20"  = "themetableau20",
@@ -417,9 +482,9 @@ h6("If you get /Error: Insufficient values in manual scale. ## needed but only 1
           tabPanel(
             "Types of Graphs",
             tabsetPanel(
-              id = "graphicaltypes",selected = "Color/Group/Split/Size/Fill Mappings (?)",
+              id = "graphicaltypes",selected = "Color/Group/Split/Size/Fill Mappings",
               tabPanel(
-                "Plot types, Points, Lines (?)",
+                "Plot types, Points, Lines",
                 
                 fluidRow(
                   
@@ -495,7 +560,7 @@ h6("If you get /Error: Insufficient values in manual scale. ## needed but only 1
                 )#fluidrow
               ), # tabpanel
               tabPanel(
-                "Color/Group/Split/Size/Fill Mappings (?)",
+                "Color/Group/Split/Size/Fill Mappings",
                 fluidRow(
                   column (12, hr()),
                   column (3, uiOutput("colour"),uiOutput("group")),
@@ -549,11 +614,27 @@ h6("If you get /Error: Insufficient values in manual scale. ## needed but only 1
                   
                   column (
                     3,
-                    checkboxInput('histogramaddition', 'Add a Histogram ?',value = FALSE)
+                    radioButtons("histogramaddition", "Add a Histogram ?",
+                                 c("Counts" = "Counts",
+                                   "Density" = "Density",
+                                   "None" = "None") ,
+                                 selected="None") ,
+                    numericInput("histobinwidth",
+                                 "N Bins",
+                                 value = 30,
+                                 min = 0, step = 0.5)
+                  
+                    
+                    
                     ),
                   column (
                     3,
-                    checkboxInput('densityaddition', 'Add a Density Curve ?',value = TRUE)
+                    radioButtons("densityaddition", "Add a Density Curve ?",
+                                 c("Density" = "Density",
+                                   "Scaled Density" = "Scaled Density",
+                                   "Counts" = "Counts",
+                                   "None" = "None") ,
+                                 selected="Density") 
                   ),
                   
                   column (
@@ -564,18 +645,25 @@ h6("If you get /Error: Insufficient values in manual scale. ## needed but only 1
                                             "Side By Side"="position_dodge(width = 0.9)",
                                             "Sum to 100%"="position_fill(vjust = 0.5)"),
                                 selected = "position_stack(vjust = 0.5)"),
-                    checkboxInput('barplotpercent', 'Show Percentage instead of Counts ?',value = FALSE),
-                    checkboxInput('barplotlabel', 'Show Labels ?',value = FALSE),
-                    checkboxInput('barplotflip', 'Flip the Barplot ?',value = FALSE)
-                    
-                  )
+                    checkboxInput('barplotpercent', 'Show Percentages instead of Counts ?',value = FALSE),
+                    checkboxInput('barplotlabel', 'Show Labels ?',value = FALSE)
+                 
+                  ),
+                  column (3,
+                          radioButtons("barplotorder", "Bar Ordering:",
+                                                       c("Default" = "default",
+                                                         "By Frequency" = "frequency",
+                                                         "By Reverse Frequency" = "revfrequency"),inline=TRUE ) ,
+                          checkboxInput('barplotflip', 'Flip the Barplot ?',value = FALSE)
+                          )
+                  
                   )
               ),
               
               
               #rqss quantile regression
               tabPanel(
-                "Quantile Regression (?)",
+                "Quantile Regression",
                 
                 fluidRow(
                   column(12,hr()),
@@ -618,7 +706,7 @@ h6("If you get /Error: Insufficient values in manual scale. ## needed but only 1
               ),
               
               tabPanel(
-                "Smooth/Linear/Logistic Regressions (?)",
+                "Smooth/Linear/Logistic Regressions",
                 
                 fluidRow(
                   column(12,hr()),
@@ -634,8 +722,14 @@ h6("If you get /Error: Insufficient values in manual scale. ## needed but only 1
                     conditionalPanel(
                       " input.Smooth!= 'None' ",
                       selectInput('smoothmethod', label ='Smoothing Method',
-                                  choices=c("Loess" ="loess","Linear Fit"="lm","Logistic"="glm"),
+                                  choices=c("Loess" ="loess","Linear Fit"="lm",
+                                            "Logistic"="glm1",
+                                            "Poisson"="glm2"),
                                   multiple=FALSE, selectize=TRUE,selected="loess"),
+                      conditionalPanel(" input.smoothmethod== 'lm' ",
+                      checkboxInput('showslopepvalue', 'Show p-value ?',value = FALSE),
+                      checkboxInput('showadjrsquared', HTML('Show R<sup>2</sup><sub>adj</sub> ?'),value = FALSE)
+                                       ),
                       conditionalPanel(" input.smoothmethod== 'loess' ",
                       sliderInput("loessens", "Loess Span:", min=0, max=1, value=c(0.75),step=0.05),
                       selectInput('loessfamily', label ='Loess Family:',
@@ -673,7 +767,7 @@ h6("If you get /Error: Insufficient values in manual scale. ## needed but only 1
               ,
               ### Mean CI section
               tabPanel(
-                "Mean CI (?)",
+                "Mean (CI)",
                 
                 fluidRow(
                   column(12,hr()),
@@ -721,7 +815,7 @@ h6("If you get /Error: Insufficient values in manual scale. ## needed but only 1
               
               
               tabPanel(
-                "Median PIs (?)",
+                "Median (PIs)",
                 
                 fluidRow(
                   column(12,hr()),
@@ -774,7 +868,7 @@ h6("If you get /Error: Insufficient values in manual scale. ## needed but only 1
               
               
               tabPanel(
-                "Kaplan-Meier (?)",
+                "Kaplan-Meier (CI)",
                 
                 fluidRow(
                   column(12,hr()),
@@ -817,12 +911,26 @@ h6("If you get /Error: Insufficient values in manual scale. ## needed but only 1
               ), #tabpanel km
               ### KM section
               tabPanel(
-                "Correlation Coefficient (?)",
+                "Correlation Coefficient",
                 fluidRow(
-                  column(12,hr()),
-                  checkboxInput('addcorrcoeff',"Add Correlation Coefficient to the plot ?"),
-                  checkboxInput('addcorrcoeffignoregroup',"Ignore Mapped Group ?", value=TRUE)
+                  column(4,hr(),
+                  checkboxInput('addcorrcoeff',
+                      "Add Correlation Coefficient to the plot ?")
+                  ),
+                  column(4,hr(),
+                  conditionalPanel(
+                    " input.addcorrcoeff ",
+                  selectInput("corrtype", label = "Correlation Method:",
+                              choices = c("pearson"="pearson",
+                                          "kendall"= "kendall",
+                                          "spearman"= "spearman"
+                                          ) ,
+                              selected = "pearson"))
+                  ),
+                  column(4,hr(),
                   
+                  checkboxInput('addcorrcoeffignoregroup',"Ignore Mapped Group ?", value=TRUE)
+                  )
                   
               )#fluidrow
               )##tabpanel corr
